@@ -19,30 +19,19 @@ import six
 
 from gradient import api_sdk
 from gradient.api_sdk.sdk_exceptions import ResourceFetchingError
-from gradient.api_sdk.utils import base64_encode
 from gradient.cli_constants import CLI_PS_CLIENT_NAME
-from gradient.cli.jobs import get_workspace_handler
-from gradient.commands import jobs as jobs_commands
 from gradient.commands.common import BaseCommand, DetailsCommandMixin, ListCommandPagerMixin
-from gradient.commands.jobs import BaseCreateJobCommandMixin, BaseJobCommand, CreateJobCommand
 from gradient.exceptions import ApplicationError
 
 S3_XMLNS = 'http://s3.amazonaws.com/doc/2006-03-01/'
-DATASET_IMPORTER_IMAGE = "paperspace/dataset-importer:latest"
-PROJECT_NAME = "Job Builder"
-SUPPORTED_URL = ['https', 'http']
-IMPORTER_COMMAND = "go-getter"
-HTTP_SECRET = "HTTP_AUTH"
-S3_ACCESS_KEY = "AWS_ACCESS_KEY_ID"
-S3_SECRET_KEY = "AWS_SECRET_ACCESS_KEY"
-S3_REGION_KEY = "AWS_DEFAULT_REGION"
 
 
 class WorkerPool(object):
 
     def __init__(self, count=None, min_count=4, max_count=16, cpu_multiplier=1):
         if count is None:
-            count = min(max(round(multiprocessing.cpu_count() * cpu_multiplier), min_count), max_count)
+            count = min(max(round(multiprocessing.cpu_count() *
+                                  cpu_multiplier), min_count), max_count)
 
         self._work = queue.Queue(maxsize=count)
         self._threads = [self._create_thread() for _ in range(count)]
@@ -234,24 +223,30 @@ class CreateDatasetVersionCommand(BaseDatasetVersionsCommand):
         if source_paths:
             for source_path in source_paths:
                 if not os.path.exists(source_path):
-                    raise ApplicationError('Source path not found: {}'.format(source_path))
+                    raise ApplicationError(
+                        'Source path not found: {}'.format(source_path))
 
         version = self.client.create(dataset_id=dataset_id, message=message)
         dataset_version_id = '{}:{}'.format(dataset_id, version)
-        self.logger.log('Created dataset version: {}'.format(dataset_version_id))
+        self.logger.log(
+            'Created dataset version: {}'.format(dataset_version_id))
 
         if source_paths:
-            create = PutDatasetFilesCommand(api_key=self.api_key, logger=self.logger)
-            create.execute(dataset_version_id, source_paths=source_paths, target_path='/')
+            create = PutDatasetFilesCommand(
+                api_key=self.api_key, logger=self.logger)
+            create.execute(dataset_version_id,
+                           source_paths=source_paths, target_path='/')
 
-            commit = CommitDatasetVersionCommand(api_key=self.api_key, logger=self.logger)
+            commit = CommitDatasetVersionCommand(
+                api_key=self.api_key, logger=self.logger)
             commit.execute(dataset_version_id)
 
 
 class UpdateDatasetVersionCommand(BaseDatasetVersionsCommand):
     def execute(self, dataset_version_id, message=None):
         self.client.update(dataset_version_id, message=message)
-        self.logger.log('Updated dataset version: {}'.format(dataset_version_id))
+        self.logger.log(
+            'Updated dataset version: {}'.format(dataset_version_id))
 
 
 class CommitDatasetVersionCommand(BaseDatasetVersionsCommand):
@@ -262,13 +257,15 @@ class CommitDatasetVersionCommand(BaseDatasetVersionsCommand):
             return
 
         self.client.update(dataset_version_id, is_committed=True)
-        self.logger.log('Committed dataset version: {}'.format(dataset_version_id))
+        self.logger.log(
+            'Committed dataset version: {}'.format(dataset_version_id))
 
 
 class DeleteDatasetVersionCommand(BaseDatasetVersionsCommand):
     def execute(self, dataset_version_id):
         self.client.delete(dataset_version_id)
-        self.logger.log('Deleted dataset version: {}'.format(dataset_version_id))
+        self.logger.log(
+            'Deleted dataset version: {}'.format(dataset_version_id))
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -324,13 +321,15 @@ class BaseDatasetFilesCommand(BaseDatasetVersionsCommand):
 
         dataset = self.dataset_client.get(dataset_id)
         if dataset.storage_provider.type != 's3':
-            raise ApplicationError('%s storage type not supported' % dataset.storage_provider.type)
+            raise ApplicationError(
+                '%s storage type not supported' % dataset.storage_provider.type)
 
     def resolve_dataset_version_id(self, dataset_ref):
         try:
             dataset_ref = self.dataset_client.get_ref(dataset_ref)
             if dataset_ref and dataset_ref.version:
-                dataset_ref = '{}:{}'.format(dataset_ref.id, dataset_ref.version.version)
+                dataset_ref = '{}:{}'.format(
+                    dataset_ref.id, dataset_ref.version.version)
         except ResourceFetchingError:
             pass
         return dataset_ref
@@ -425,7 +424,8 @@ class BaseDatasetFilesCommand(BaseDatasetVersionsCommand):
 
                     result = {'key': key_prefix + key}
                     if not is_dir:
-                        result['size'] = item.find('{' + S3_XMLNS + '}Size').text
+                        result['size'] = item.find(
+                            '{' + S3_XMLNS + '}Size').text
 
                     results.append(result)
                 elif name == 'NextContinuationToken':
@@ -433,7 +433,8 @@ class BaseDatasetFilesCommand(BaseDatasetVersionsCommand):
                 elif name == 'CommonPrefixes':
                     if recursive:
                         continue
-                    key = item.find('{' + S3_XMLNS + '}Prefix').text[len(prefix):]
+                    key = item.find(
+                        '{' + S3_XMLNS + '}Prefix').text[len(prefix):]
                     results.append({'key': key_prefix + key})
 
             yield results, bool(next_continuation_token)
@@ -455,7 +456,8 @@ class ListDatasetFilesCommand(ListCommandPagerMixin, BaseDatasetFilesCommand):
     def _get_instances(self, kwargs):
         self.assert_supported(kwargs['dataset_version_id'])
 
-        kwargs['dataset_version_id'] = self.resolve_dataset_version_id(kwargs['dataset_version_id'])
+        kwargs['dataset_version_id'] = self.resolve_dataset_version_id(
+            kwargs['dataset_version_id'])
 
         return self.list_objects(**kwargs)
 
@@ -491,7 +493,8 @@ class GetDatasetFilesCommand(BaseDatasetFilesCommand):
     def execute(self, dataset_version_id, source_paths, target_path):
         self.assert_supported(dataset_version_id)
 
-        dataset_version_id = self.resolve_dataset_version_id(dataset_version_id)
+        dataset_version_id = self.resolve_dataset_version_id(
+            dataset_version_id)
 
         target_path = os.path.abspath(target_path)
 
@@ -510,7 +513,8 @@ class GetDatasetFilesCommand(BaseDatasetFilesCommand):
                     has_trailing_slash = source_path.endswith('/')
 
                     if not has_trailing_slash:
-                        result = self.get_object(dataset_version_id, source_path)
+                        result = self.get_object(
+                            dataset_version_id, source_path)
                         if result is not None:
                             list_objects = [([result], False)]
                             is_file = True
@@ -525,7 +529,8 @@ class GetDatasetFilesCommand(BaseDatasetFilesCommand):
                         )
 
                     def update_status():
-                        status.text = '{}: {} ({})  '.format(status_text, source_path, pool.completed_count())
+                        status.text = '{}: {} ({})  '.format(
+                            status_text, source_path, pool.completed_count())
 
                     for results, _ in list_objects:
                         if not results:
@@ -533,14 +538,16 @@ class GetDatasetFilesCommand(BaseDatasetFilesCommand):
 
                         pre_signeds = self.client.generate_pre_signed_s3_urls(
                             dataset_version_id,
-                            calls=[dict(method='getObject', params=dict(Key=r['key'])) for r in results],
+                            calls=[dict(method='getObject', params=dict(
+                                Key=r['key'])) for r in results],
                         )
 
                         for result, pre_signed in zip(results, pre_signeds):
                             if is_file:
                                 path = target_path
                             elif has_trailing_slash:
-                                path = os.path.join(target_path, result['key'][len(source_path)-1:])
+                                path = os.path.join(
+                                    target_path, result['key'][len(source_path)-1:])
                             else:
                                 path = os.path.join(target_path, result['key'])
 
@@ -560,7 +567,8 @@ class PutDatasetFilesCommand(BaseDatasetFilesCommand):
             try:
                 if size > 0:
                     with open(path, 'rb') as f:
-                        r = session.put(url, data=f, headers=headers, timeout=5)
+                        r = session.put(
+                            url, data=f, headers=headers, timeout=5)
                 else:
                     headers.update({'Content-Size': '0'})
                     r = session.put(url, data='', headers=headers, timeout=5)
@@ -586,12 +594,14 @@ class PutDatasetFilesCommand(BaseDatasetFilesCommand):
     def _sign_and_put(self, dataset_version_id, pool, results, update_status):
         pre_signeds = self.client.generate_pre_signed_s3_urls(
             dataset_version_id,
-            calls=[dict(method='putObject', params=dict(Key=r['key'], ContentType=r['mimetype'])) for r in results],
+            calls=[dict(method='putObject', params=dict(
+                Key=r['key'], ContentType=r['mimetype'])) for r in results],
         )
 
         for pre_signed, result in zip(pre_signeds, results):
             update_status()
-            pool.put(self._put, url=pre_signed.url, path=result['path'], content_type=result['mimetype'])
+            pool.put(self._put, url=pre_signed.url,
+                     path=result['path'], content_type=result['mimetype'])
 
     def execute(self, dataset_version_id, source_paths, target_path):
         self.assert_supported(dataset_version_id)
@@ -613,7 +623,8 @@ class PutDatasetFilesCommand(BaseDatasetFilesCommand):
                     source_name = os.path.basename(source_path)
 
                     def update_status():
-                        status.text = '{}: {} ({})'.format(status_text, source_path, pool.completed_count())
+                        status.text = '{}: {} ({})'.format(
+                            status_text, source_path, pool.completed_count())
 
                     results = []
 
@@ -626,16 +637,20 @@ class PutDatasetFilesCommand(BaseDatasetFilesCommand):
                                 key += source_name + '/'
                             key += path[len(source_path)+1:]
 
-                        mimetype = mimetypes.guess_type(key)[0] or 'application/octet-stream'
+                        mimetype = mimetypes.guess_type(
+                            key)[0] or 'application/octet-stream'
 
-                        results.append(dict(key=key, path=path, mimetype=mimetype))
+                        results.append(
+                            dict(key=key, path=path, mimetype=mimetype))
 
                         if len(results) == pool.worker_count:
-                            self._sign_and_put(dataset_version_id, pool, results, update_status)
+                            self._sign_and_put(
+                                dataset_version_id, pool, results, update_status)
                             results = []
 
                     if results:
-                        self._sign_and_put(dataset_version_id, pool, results, update_status)
+                        self._sign_and_put(
+                            dataset_version_id, pool, results, update_status)
 
 
 class DeleteDatasetFilesCommand(BaseDatasetFilesCommand):
@@ -663,7 +678,8 @@ class DeleteDatasetFilesCommand(BaseDatasetFilesCommand):
                     has_trailing_slash = path.endswith('/')
 
                     def update_status():
-                        status.text = '{}: {} ({})'.format(status_text, path, pool.completed_count())
+                        status.text = '{}: {} ({})'.format(
+                            status_text, path, pool.completed_count())
 
                     if not has_trailing_slash:
                         result = self.get_object(dataset_version_id, path)
@@ -684,98 +700,10 @@ class DeleteDatasetFilesCommand(BaseDatasetFilesCommand):
 
                         pre_signeds = self.client.generate_pre_signed_s3_urls(
                             dataset_version_id,
-                            calls=[dict(method='deleteObject', params=dict(Key=r['key'])) for r in results],
+                            calls=[dict(method='deleteObject', params=dict(
+                                Key=r['key'])) for r in results],
                         )
 
                         for pre_signed in pre_signeds:
                             update_status()
                             pool.put(self._delete, url=pre_signed.url)
-
-
-class ImportDatasetCommand(BaseCreateJobCommandMixin):
-    def create_secret(self, key, value, expires_in=86400):
-        client = api_sdk.clients.SecretsClient(
-            api_key=self.api_key,
-            logger=self.logger,
-            ps_client_name=CLI_PS_CLIENT_NAME,
-        )
-
-        response = client.ephemeral(key, value, expires_in)
-        return response
-
-    def get_command(self, s3_url, http_url, http_auth):
-        command = "%s %s /data/output" % (IMPORTER_COMMAND, (s3_url or http_url))
-        if s3_url:
-            command = "%s s3::%s /data/output" % (IMPORTER_COMMAND, s3_url)
-
-        if http_url and http_auth is not None:
-            url = urlparse(http_url)
-            command_string = "%s https://${{HTTP_AUTH}}@%s /data/output" % (IMPORTER_COMMAND, url.path)
-            command = base64_encode(command_string)
-
-        return command
-    
-    def get_env_vars(self, s3_url, http_url, secrets):
-        if s3_url is not None:
-            if secrets[S3_ACCESS_KEY] is None or secrets[S3_SECRET_KEY] is None:
-                self.logger.log('s3AccessKey and s3SecretKey required')
-                return 
-
-            access_key_secret = self.create_secret(S3_ACCESS_KEY, secrets[S3_ACCESS_KEY])
-            secret_key_secret = self.create_secret(S3_SECRET_KEY, secrets[S3_SECRET_KEY])
-
-            access_key_value = "secret:ephemeral:%s" % access_key_secret[S3_ACCESS_KEY]
-            secret_key_value = "secret:ephemeral:%s" % secret_key_secret[S3_SECRET_KEY]
-
-            return {
-                S3_ACCESS_KEY: access_key_value,
-                S3_SECRET_KEY: secret_key_value,
-            }
-
-        if http_url and secrets[S3_ACCESS_KEY] is not None:
-            http_auth_secret = self.create_secret(HTTP_SECRET, secrets[HTTP_SECRET])
-            return {
-                HTTP_SECRET: http_auth_secret
-            }
-        
-        return ""
-
-    def _create(self, workflow):
-        client = api_sdk.clients.JobsClient(
-            api_key=self.api_key,
-            ps_client_name=CLI_PS_CLIENT_NAME,
-        )
-        return self.client.create(**workflow)
-
-
-    def execute(self, cluster_id, machine_type, dataset_id, s3_url, http_url, http_auth, access_key, secret_key):
-        if s3_url is None and http_url is None:
-            self.logger.log('Error: --s3Url or --httpUrl required')
-            return
-
-        workflow = {
-            "cluster_id": cluster_id,
-            "container": DATASET_IMPORTER_IMAGE,
-            "machine_type": machine_type,
-            "project": PROJECT_NAME,
-            "datasets": [{ "id": dataset_id, "name": "output", "output": True }],
-            "project_id": None
-        }
-
-        dataset_url = s3_url or http_url
-
-        url = urlparse(dataset_url)
-        if url.scheme not in SUPPORTED_URL:
-            self.logger.log('Invalid URL format supported [{}] Format:{} URL:{}'.format(','.join(SUPPORTED_URL), url.scheme, dataset_url))
-            return
-
-        command = self.get_command(s3_url, http_url, http_auth)
-        if command:
-            workflow["command"] = command
-
-        env_vars = self.get_env_vars(s3_url, http_url, { HTTP_SECRET: http_auth, S3_ACCESS_KEY: access_key, S3_SECRET_KEY: secret_key })
-        if env_vars:
-            workflow["env_vars"] = env_vars
-
-        command = CreateJobCommand(api_key=self.api_key, workspace_handler=get_workspace_handler())
-        command.execute(workflow)
